==> mlt.docreg_1.0-1.tar.gz: mlt.docreg/inst/NEWS.Rd <==

\name{NEWS}
\title{NEWS file for the mlt.docreg package}

\section{Changes in Version 1.0-1 (2018-06-22)}{
  \itemize{
    \item{Documentation updates.}
    \item{Update to \pkg{mlt} 1.0-2.}
  }
}

\section{Changes in Version 1.0-0 (2018-03-07)}{
  \itemize{
    \item{A paper describing version 1.0-0 of the \pkg{mlt}, \pkg{basefun}, and
          \pkg{variables} packages was accepted for publication in the Journal of
          Statistical Software 2018-03-05.}
    \item{Documentation updates.}
  }
}

\section{Changes in Version 0.2-2 (2018-02-27)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.2-2.}
    \item{Vignette updates; add link to simpler interfaces
          in \pkg{tram}.}
  }
}

\section{Changes in Version 0.2-1 (2017-12-12)}{
  \itemize{
    \item{Update citations.}
  }
}


\section{Changes in Version 0.2-0 (2017-06-20)}{
  \itemize{
    \item{Most Likely Transformations will be published in
          the Scandinavian Journal of Statistics.}
    \item{Update to \code{mlt} 0.2-0.}
    \item{Remove \pkg{alabama} from Suggests as it is imported by
          \pkg{mlt} now.}
  }
}


\section{Changes in Version 0.1-5 (2017-04-04)}{
  \itemize{
    \item{Update to \code{mlt} 0.1-3.}
    \item{Improvements in package vignette (mainly thanks to Eva Furrer).}
  }
}

\section{Changes in Version 0.1-4 (2016-12-04)}{
  \itemize{
    \item{More tests were a little too strict on non-Linux platforms.}
    \item{\code{auglag} does not seem to converge to the ML estimate for the
          tree pipit example; force \code{sgp} to be used.}
  }
}


\section{Changes in Version 0.1-3 (2016-12-01)}{
  \itemize{
    \item{Some tests were a little too strict on non-Linux platforms.}
  }
}

\section{Changes in Version 0.1-2 (2016-11-29)}{
  \itemize{
    \item{Add tests for survival models with time-dependent covariates.}
  }
}

\section{Changes in Version 0.1-1 (2016-11-17)}{
  \itemize{
    \item{Some fixes in vignette.}
  }
}

\section{Changes in Version 0.1-0 (2016-11-09)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.1-0; small fixes in vignette and reference outputs.}
  }
}

\section{Changes in Version 0.0-33 (2016-09-12)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.0-34; small fixes in vignette.}
  }
}

\section{Changes in Version 0.0-32 (2016-05-25)}{
  \itemize{
    \item{Remove \pkg{intcox} as the package is archived now.}
  }
}

\section{Changes in Version 0.0-30 (2016-02-23)}{
  \itemize{
    \item{The \pkg{mlt.docreg} package was first 
          published on CRAN.}
  }
}

==> mlt.docreg_1.0-2.tar.gz: mlt.docreg/inst/NEWS.Rd <==

\name{NEWS}
\title{NEWS file for the mlt.docreg package}

\section{Changes in Version 1.0-2 (2018-08-15)}{
  \itemize{
    \item{\code{compress} argment to \code{untar} is deprecated in R-devel.}
  }
}

\section{Changes in Version 1.0-1 (2018-06-22)}{
  \itemize{
    \item{Documentation updates.}
    \item{Update to \pkg{mlt} 1.0-2.}
  }
}


\section{Changes in Version 1.0-0 (2018-03-07)}{
  \itemize{
    \item{A paper describing version 1.0-0 of the \pkg{mlt}, \pkg{basefun}, and
          \pkg{variables} packages was accepted for publication in the Journal of
          Statistical Software 2018-03-05.}
    \item{Documentation updates.}
  }
}

\section{Changes in Version 0.2-2 (2018-02-27)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.2-2.}
    \item{Vignette updates; add link to simpler interfaces
          in \pkg{tram}.}
  }
}

\section{Changes in Version 0.2-1 (2017-12-12)}{
  \itemize{
    \item{Update citations.}
  }
}


\section{Changes in Version 0.2-0 (2017-06-20)}{
  \itemize{
    \item{Most Likely Transformations will be published in
          the Scandinavian Journal of Statistics.}
    \item{Update to \code{mlt} 0.2-0.}
    \item{Remove \pkg{alabama} from Suggests as it is imported by
          \pkg{mlt} now.}
  }
}


\section{Changes in Version 0.1-5 (2017-04-04)}{
  \itemize{
    \item{Update to \code{mlt} 0.1-3.}
    \item{Improvements in package vignette (mainly thanks to Eva Furrer).}
  }
}

\section{Changes in Version 0.1-4 (2016-12-04)}{
  \itemize{
    \item{More tests were a little too strict on non-Linux platforms.}
    \item{\code{auglag} does not seem to converge to the ML estimate for the
          tree pipit example; force \code{sgp} to be used.}
  }
}


\section{Changes in Version 0.1-3 (2016-12-01)}{
  \itemize{
    \item{Some tests were a little too strict on non-Linux platforms.}
  }
}

\section{Changes in Version 0.1-2 (2016-11-29)}{
  \itemize{
    \item{Add tests for survival models with time-dependent covariates.}
  }
}

\section{Changes in Version 0.1-1 (2016-11-17)}{
  \itemize{
    \item{Some fixes in vignette.}
  }
}

\section{Changes in Version 0.1-0 (2016-11-09)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.1-0; small fixes in vignette and reference outputs.}
  }
}

\section{Changes in Version 0.0-33 (2016-09-12)}{
  \itemize{
    \item{Update to \pkg{mlt} 0.0-34; small fixes in vignette.}
  }
}

\section{Changes in Version 0.0-32 (2016-05-25)}{
  \itemize{
    \item{Remove \pkg{intcox} as the package is archived now.}
  }
}

\section{Changes in Version 0.0-30 (2016-02-23)}{
  \itemize{
    \item{The \pkg{mlt.docreg} package was first 
          published on CRAN.}
  }
}
